@@ -849,76 +849,66 @@ func TestGetRemoteURL(t *testing.T) {
 	}
 }
 
-type featureFlagOnTestCase struct {
-	value          string
-	expectedStatus bool
-	expectedError  bool
-}
-
 func TestIsFeatureFlagOn(t *testing.T) {
-	hook := test.NewGlobal()
+	const testFF = "FF_TEST_FEATURE"
 
-	tests := map[string]featureFlagOnTestCase{
+	tests := map[string]struct {
+		featureFlagCfg map[string]bool
+		value          string
+		expectedStatus bool
+	}{
 		"no value": {
 			value:          "",
 			expectedStatus: false,
-			expectedError:  false,
 		},
 		"true": {
 			value:          "true",
 			expectedStatus: true,
-			expectedError:  false,
 		},
 		"1": {
 			value:          "1",
 			expectedStatus: true,
-			expectedError:  false,
 		},
 		"false": {
 			value:          "false",
 			expectedStatus: false,
-			expectedError:  false,
 		},
 		"0": {
 			value:          "0",
 			expectedStatus: false,
-			expectedError:  false,
 		},
 		"invalid value": {
 			value:          "test",
 			expectedStatus: false,
-			expectedError:  true,
+		},
+		"feature flag set inside config.toml take precedence": {
+			featureFlagCfg: map[string]bool{
+				testFF: true,
+			},
+			value:          "false",
+			expectedStatus: true,
 		},
 	}
 
 	for name, testCase := range tests {
 		t.Run(name, func(t *testing.T) {
 			build := new(Build)
+			build.Runner = &RunnerConfig{
+				RunnerSettings: RunnerSettings{
+					FeatureFlags: testCase.featureFlagCfg,
+				},
+			}
 			build.Variables = JobVariables{
-				{Key: "FF_TEST_FEATURE", Value: testCase.value},
+				{Key: testFF, Value: testCase.value},
 			}
 
-			status := build.IsFeatureFlagOn("FF_TEST_FEATURE")
+			status := build.IsFeatureFlagOn(testFF)
 			assert.Equal(t, testCase.expectedStatus, status)
-
-			entry := hook.LastEntry()
-			if testCase.expectedError {
-				require.NotNil(t, entry)
-
-				logrusOutput, err := entry.String()
-				require.NoError(t, err)
-
-				assert.Contains(t, logrusOutput, "Error while parsing the value of feature flag")
-			} else {
-				assert.Nil(t, entry)
-			}
-
-			hook.Reset()
 		})
 	}
 }
 
-func TestAllowToOverwriteFeatureFlagWithRunnerVariables(t *testing.T) {
+func TestIsFeatureFlagOn_SetWithRunnerVariables(t *testing.T) {
 	tests := map[string]struct {
 		variable      string
 		expectedValue bool
@@ -952,6 +942,61 @@ func TestAllowToOverwriteFeatureFlagWithRunnerVariables(t *testing.T) {
 	}
 }
 
+func TestIsFeatureFlagOn_Precedence(t *testing.T) {
+	const testFF = "FF_TEST_FEATURE"
+
+	t.Run("config takes precedence over job variable", func(t *testing.T) {
+		b := &Build{
+			Runner: &RunnerConfig{
+				RunnerSettings: RunnerSettings{
+					FeatureFlags: map[string]bool{
+						testFF: true,
+					},
+				},
+			},
+			JobResponse: JobResponse{
+				Variables: JobVariables{
+					{Key: testFF, Value: "false"},
+				},
+			},
+		}
+
+		assert.True(t, b.IsFeatureFlagOn(testFF))
+	})
+
+	t.Run("config takes precedence over configured environments", func(t *testing.T) {
+		b := &Build{
+			Runner: &RunnerConfig{
+				RunnerSettings: RunnerSettings{
+					FeatureFlags: map[string]bool{
+						testFF: true,
+					},
+					Environment: []string{testFF + "=false"},
+				},
+			},
+		}
+
+		assert.True(t, b.IsFeatureFlagOn(testFF))
+	})
+
+	t.Run("variable defined at job take precedence over configured environments", func(t *testing.T) {
+		b := &Build{
+			Runner: &RunnerConfig{
+				RunnerSettings: RunnerSettings{
+					Environment: []string{testFF + "=false"},
+				},
+			},
+			JobResponse: JobResponse{
+				Variables: JobVariables{
+					{Key: testFF, Value: "true"},
+				},
+			},
+		}
+
+		assert.True(t, b.IsFeatureFlagOn(testFF))
+	})
+}
+
 func TestStartBuild(t *testing.T) {
 	type startBuildArgs struct {
 		rootDir               string
@@ -1509,22 +1554,6 @@ func TestProjectUniqueName(t *testing.T) {
 			},
 			expectedName: "runner-zen8e6e-project-1234567890-concurrent-0",
 		},
-		"project non rfc1132 unique name longer than 63 char": {
-			build: &Build{
-				Runner: &RunnerConfig{
-					RunnerCredentials: RunnerCredentials{
-						Token: "Ze_n8E6en622WxxSg4r8",
-					},
-				},
-				JobResponse: JobResponse{
-					JobInfo: JobInfo{
-						ProjectID: 123456789012345,
-					},
-				},
-				ProjectRunnerID: 123456789012345,
-			},
-			expectedName: "runner-zen8e6e-project-123456789012345-concurrent-1234567890123",
-		},
 		"project normal unique name": {
 			build: &Build{
 				Runner: &RunnerConfig{
@@ -1659,6 +1688,7 @@ func TestBuild_getFeatureFlagInfo(t *testing.T) {
 						},
 					},
 				},
+				Runner: &RunnerConfig{},
 			}
 
 			assert.Equal(t, tt.expectedStatus, b.getFeatureFlagInfo())
