@@ -1,7 +1,6 @@
 package docker
 
 import (
-	"bytes"
 	"context"
 	"errors"
 	"flag"
@@ -12,9 +11,7 @@ import (
 	"regexp"
 	"runtime"
 	"strings"
-	"sync"
 	"testing"
-	"time"
 
 	"github.com/docker/docker/api/types"
 	"github.com/docker/docker/api/types/container"
@@ -29,9 +26,9 @@ import (
 	"gitlab.com/gitlab-org/gitlab-runner/executors"
 	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/networks"
 	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/pull"
+	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/user"
 	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/volumes"
 	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/volumes/parser"
-	"gitlab.com/gitlab-org/gitlab-runner/helpers"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/container/helperimage"
 	service_test "gitlab.com/gitlab-org/gitlab-runner/helpers/container/services/test"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/docker"
@@ -332,17 +329,6 @@ func TestHelperImageWithVariable(t *testing.T) {
 	assert.Equal(t, "helper-image", img.ID)
 }
 
-// setPolicyMode is only meant to be used for tests. If called with an empty array, it will clear out the pull policies.
-func (e *executor) setPolicyMode(pullPolicies ...common.DockerPullPolicy) {
-	e.Config = common.RunnerConfig{
-		RunnerSettings: common.RunnerSettings{
-			Docker: &common.DockerConfig{
-				PullPolicy: pullPolicies,
-			},
-		},
-	}
-}
-
 func TestPrepareBuildsDir(t *testing.T) {
 	tests := map[string]struct {
 		parser                  parser.Parser
@@ -891,82 +877,6 @@ func TestCreateDependencies(t *testing.T) {
 	assert.Equal(t, testError, err)
 }
 
-func TestDockerWatchOn_1_12_4(t *testing.T) {
-	test.SkipIfGitLabCIOn(t, test.OSWindows)
-	helpers.SkipIntegrationTests(t, "docker", "info")
-
-	e := &executor{
-		AbstractExecutor: executors.AbstractExecutor{
-			ExecutorOptions: executors.ExecutorOptions{
-				Metadata: map[string]string{
-					metadataOSType: osTypeLinux,
-				},
-			},
-		},
-		volumeParser: parser.NewLinuxParser(),
-	}
-	e.Context = context.Background()
-	e.Build = &common.Build{
-		Runner: &common.RunnerConfig{},
-	}
-	e.Build.Token = "abcd123456"
-	e.BuildShell = &common.ShellConfiguration{
-		Environment: []string{},
-	}
-
-	e.Config = common.RunnerConfig{}
-	e.Config.Docker = &common.DockerConfig{
-		PullPolicy: common.DockerPullPolicies{common.PullPolicyIfNotPresent},
-	}
-
-	output := bytes.NewBufferString("")
-	e.Trace = &common.Trace{Writer: output}
-
-	err := e.connectDocker()
-	require.NoError(t, err)
-
-	err = e.createVolumesManager()
-	require.NoError(t, err)
-
-	err = e.createLabeler()
-	require.NoError(t, err)
-
-	err = e.createPullManager()
-	require.NoError(t, err)
-
-	container, err := e.createContainer(
-		"build",
-		common.Image{Name: common.TestAlpineImage},
-		[]string{"/bin/sh"},
-		[]string{},
-	)
-	assert.NoError(t, err)
-	assert.NotNil(t, container)
-
-	input := bytes.NewBufferString("echo 'script'")
-
-	finished := make(chan bool, 1)
-	wg := &sync.WaitGroup{}
-	wg.Add(1) // Avoid a race where assert.NoError() is called too late in the goroutine
-	go func() {
-		err = e.startAndWatchContainer(e.Context, container.ID, input)
-		assert.NoError(t, err)
-		finished <- true
-		wg.Done()
-	}()
-
-	select {
-	case <-finished:
-		assert.Equal(t, "script\n", output.String())
-	case <-time.After(15 * time.Second):
-		t.Error("Container script not finished")
-	}
-
-	err = e.removeContainer(e.Context, container.ID)
-	assert.NoError(t, err)
-	wg.Wait()
-}
-
 type containerConfigExpectations func(*testing.T, *container.Config, *container.HostConfig)
 
 type dockerConfigurationTestFakeDockerClient struct {
@@ -2153,6 +2063,7 @@ func TestLocalHelperImage(t *testing.T) {
 						JobResponse: common.JobResponse{
 							Variables: tt.jobVariables,
 						},
+						Runner: &common.RunnerConfig{},
 					},
 
 					Config: common.RunnerConfig{
@@ -2196,6 +2107,63 @@ func createFakePrebuiltImages(t *testing.T, architecture string) func() {
 	}
 }
 
+func TestGetUIDandGID(t *testing.T) {
+	ctx := context.Background()
+	testContainerID := "test-ID"
+	testImageSHA := "test-SHA"
+	testUID := 456
+	testGID := 789
+
+	tests := map[string]struct {
+		mockInspect   func(t *testing.T, i *user.MockInspect)
+		expectedError error
+	}{
+		"UID check returns error": {
+			mockInspect: func(t *testing.T, i *user.MockInspect) {
+				i.On("UID", ctx, testContainerID).Return(0, assert.AnError).Once()
+			},
+			expectedError: assert.AnError,
+		},
+		"UID check succeeds, GID check returns error": {
+			mockInspect: func(t *testing.T, i *user.MockInspect) {
+				i.On("UID", ctx, testContainerID).Return(testUID, nil).Once()
+				i.On("GID", ctx, testContainerID).Return(0, assert.AnError).Once()
+			},
+			expectedError: assert.AnError,
+		},
+		"both checks succeed": {
+			mockInspect: func(t *testing.T, i *user.MockInspect) {
+				i.On("UID", ctx, testContainerID).Return(testUID, nil).Once()
+				i.On("GID", ctx, testContainerID).Return(testGID, nil).Once()
+			},
+			expectedError: nil,
+		},
+	}
+
+	for tn, tt := range tests {
+		t.Run(tn, func(t *testing.T) {
+			inspectMock := new(user.MockInspect)
+			defer inspectMock.AssertExpectations(t)
+
+			tt.mockInspect(t, inspectMock)
+
+			log, _ := logrustest.NewNullLogger()
+			uid, gid, err := getUIDandGID(ctx, log, inspectMock, testContainerID, testImageSHA)
+
+			if tt.expectedError != nil {
+				assert.Equal(t, 0, uid)
+				assert.Equal(t, 0, gid)
+				assert.ErrorIs(t, err, tt.expectedError)
+				return
+			}
+
+			assert.NoError(t, err)
+			assert.Equal(t, testUID, uid)
+			assert.Equal(t, testGID, gid)
+		})
+	}
+}
+
 func init() {
 	auth.HomeDirectory = ""
 }
