@@ -15,6 +15,7 @@ import (
 
 	"gitlab.com/gitlab-org/gitlab-runner/common"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/docker"
+	"gitlab.com/gitlab-org/gitlab-runner/helpers/featureflags"
 )
 
 var machineDefaultConfig = &common.RunnerConfig{
@@ -35,6 +36,18 @@ var machineCreateFail = &common.RunnerConfig{
 	},
 }
 
+var machineCreateFailSkipProvision = &common.RunnerConfig{
+	RunnerSettings: common.RunnerSettings{
+		Machine: &common.DockerMachine{
+			MachineName: "create-fail-%s",
+			IdleTime:    5,
+		},
+		FeatureFlags: map[string]bool{
+			featureflags.SkipDockerMachineProvisionOnCreationFailure: true,
+		},
+	},
+}
+
 var machineProvisionFail = &common.RunnerConfig{
 	RunnerSettings: common.RunnerSettings{
 		Machine: &common.DockerMachine{
@@ -307,6 +320,15 @@ func TestMachineCreationAndRemoval(t *testing.T) {
 	assert.Equal(t, machineStateRemoving, d.State)
 }
 
+func TestMachineCreation_SkipProvisionOnFailure(t *testing.T) {
+	p, _ := testMachineProvider()
+
+	m, errCh := p.create(machineCreateFailSkipProvision, machineStateUsed)
+	assert.NotNil(t, m)
+	assert.Error(t, <-errCh, "failed to create")
+	assert.Equal(t, machineStateRemoving, m.State)
+}
+
 func TestMachineUse(t *testing.T) {
 	provisionRetryInterval = 0
 
