@@ -21,6 +21,8 @@ const (
 	EnableBashExitCodeCheck                     string = "FF_ENABLE_BASH_EXIT_CODE_CHECK"
 	UseWindowsLegacyProcessStrategy             string = "FF_USE_WINDOWS_LEGACY_PROCESS_STRATEGY"
 	SkipDockerMachineProvisionOnCreationFailure string = "FF_SKIP_DOCKER_MACHINE_PROVISION_ON_CREATION_FAILURE"
+	UseNewEvalStrategy                          string = "FF_USE_NEW_BASH_EVAL_STRATEGY"
+	UsePowershellPathResolver                   string = "FF_USE_POWERSHELL_PATH_RESOLVER"
 )
 
 type FeatureFlag struct {
@@ -160,6 +162,22 @@ var flags = []FeatureFlag{
 			"this feature flag is set to `true`, it skips `docker-machine provision` " +
 			"removes the machine, and creates another machine instead.",
 	},
+	{
+		Name:            UseNewEvalStrategy,
+		DefaultValue:    false,
+		Deprecated:      false,
+		ToBeRemovedWith: "",
+		Description: "When set to `true`, the Bash `eval` call is executed in a subshell to help with proper exit " +
+			"code detection of the script executed.",
+	},
+	{
+		Name:            UsePowershellPathResolver,
+		DefaultValue:    false,
+		Deprecated:      false,
+		ToBeRemovedWith: "",
+		Description: "When enabled, Powershell resolves pathnames rather than Runner using OS-specific filepath " +
+			"functions that are specific to where Runner is hosted.",
+	},
 }
 
 func GetAll() []FeatureFlag {
