@@ -2,7 +2,9 @@ package trace
 
 import (
 	"math"
+	"sync"
 	"testing"
+	"unicode/utf8"
 
 	url_helpers "gitlab.com/gitlab-org/gitlab-runner/helpers/url"
 
@@ -11,13 +13,14 @@ import (
 )
 
 func TestVariablesMasking(t *testing.T) {
-	traceMessage := "This is the secret message cont@ining :secret duplicateValues"
+	traceMessage := "This is the secret message cont@ining :secret duplicateValues ffixx"
 	maskedValues := []string{
 		"is",
 		"duplicateValue",
 		"duplicateValue",
 		":secret",
 		"cont@ining",
+		"fix",
 	}
 
 	buffer, err := New()
@@ -34,7 +37,7 @@ func TestVariablesMasking(t *testing.T) {
 	content, err := buffer.Bytes(0, 1000)
 	require.NoError(t, err)
 
-	assert.Equal(t, "Th[MASKED] [MASKED] the secret message [MASKED] [MASKED] [MASKED]s", string(content))
+	assert.Equal(t, "Th[MASKED] [MASKED] the secret message [MASKED] [MASKED] [MASKED]s f[MASKED]x", string(content))
 }
 
 func TestTraceLimit(t *testing.T) {
@@ -119,6 +122,62 @@ func TestDelayedLimit(t *testing.T) {
 	assert.Equal(t, expectedContent, string(content))
 }
 
+func TestTraceRace(t *testing.T) {
+	buffer, err := New()
+	require.NoError(t, err)
+	defer buffer.Close()
+
+	buffer.SetLimit(1000)
+
+	load := []func(){
+		func() { _, _ = buffer.Write([]byte("x")) },
+		func() { buffer.SetMasked([]string{"x"}) },
+		func() { buffer.SetLimit(1000) },
+		func() { buffer.Checksum() },
+		func() { buffer.Size() },
+	}
+
+	var wg sync.WaitGroup
+	for _, fn := range load {
+		wg.Add(1)
+		go func(fn func()) {
+			defer wg.Done()
+
+			for i := 0; i < 100; i++ {
+				fn()
+			}
+		}(fn)
+	}
+
+	wg.Wait()
+
+	buffer.Finish()
+
+	_, err = buffer.Bytes(0, 1000)
+	require.NoError(t, err)
+}
+
+func TestFixupInvalidUTF8(t *testing.T) {
+	buffer, err := New()
+	require.NoError(t, err)
+	defer buffer.Close()
+
+	buffer.SetMasked([]string{"hello", "\xfe"})
+
+	// \xfe and \xff are both invalid
+	// \xfe we're masking though, so will be replaced with [MASKED]
+	// \xff will be replaced by the "unicode replacement character" \ufffd
+	// this ensures that masking happens prior to the utf8 fix
+	_, err = buffer.Write([]byte("hello a\xfeb a\xffb\n"))
+	require.NoError(t, err)
+
+	content, err := buffer.Bytes(0, 1000)
+	require.NoError(t, err)
+
+	assert.True(t, utf8.ValidString(string(content)))
+	assert.Equal(t, "[MASKED] a[MASKED]b a\ufffdb\n", string(content))
+}
+
 const logLineStr = "hello world, this is a lengthy log line including secrets such as 'hello', and " +
 	"https://example.com/?rss_token=foo&rss_token=bar and http://example.com/?authenticity_token=deadbeef and " +
 	"https://example.com/?rss_token=foobar. it's longer than most log lines, but probably a good test for " +
