@@ -4,7 +4,9 @@ import (
 	"regexp"
 )
 
-var scrubRegexp = regexp.MustCompile(`(?im)([\?&]((?:private|authenticity|rss)[\-_]token)|X-AMZ-Signature|X-AMZ-Credential)=[^& ]*`)
+var scrubRegexp = regexp.MustCompile(
+	`(?im)([\?&]((?:private|authenticity|rss)[\-_]token)|X-AMZ-Signature|X-AMZ-Credential)=[^& ]*`,
+)
 
 // ScrubSecrets replaces the content of any sensitive query string parameters
 // in a URL with `[FILTERED]`
